@@ -29,7 +29,7 @@ function(y, d, log=FALSE)
           for(k in i1:jn)
             xnew[k] <- x1 - jot + (k - i1) * d
           i1 <- jn + 1
-          nobounce <- F
+          nobounce <- FALSE
           break
         }
       }
@@ -39,7 +39,7 @@ function(y, d, log=FALSE)
     if(min(diff(xnew)) < d * 0.999) {
       n1 <- (1:(n - 1))[diff(xnew) < d]
       cat("Error in bounce().  Improperly separated points are:",
-          fill = T)
+          fill = TRUE)
       cat(paste(n1, ":", n1 + 1, sep = ""), fill = TRUE)
       cat(paste(xnew[n1], ":", xnew[n1 + 1], sep = ""), fill
           = TRUE)
